project_input_data

Function project_input_data 

pub fn project_input_data(
    input_data: &RecordBatch,
    model_input_schema: SchemaRef,
) -> Result<RecordBatch>
Transform the input_data to match the model_input_schema. Input data columns are projected and cast to the corresponding input schema columns.

This is necessary because the input_data may have extra columns or have different datatypes.